// Some utility functions for constructing common messages in the messengers.
// (Most message functionality is in the library, not this module.)

/// Construct and serialize a message from the sender to the recipients with the given number of blocks.
pub fn construct_message(
    sender: String,
    recipients: Vec<String>,
    blocks: u32,
) -> mgen::SerializedMessage {
    let size = std::cmp::max(blocks, 1) * mgen::PADDING_BLOCK_SIZE;
    let m = mgen::MessageHeader {
        sender,
        recipients,
        body: mgen::MessageBody::Size(std::num::NonZeroU32::new(size).unwrap()),
    };
    m.serialize()
}

pub fn construct_receipt(sender: String, recipient: String) -> mgen::SerializedMessage {
    let m = mgen::MessageHeader {
        sender,
        recipients: vec![recipient],
        body: mgen::MessageBody::Receipt,
    };
    m.serialize()
}
